/*
 *  File: IViewstateSaver.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.util.ui.timebars.addon;

import org.eclipse.ui.IMemento;

import de.jaret.util.ui.timebars.swt.TimeBarViewer;

/**
 * Interface for a service saving and restoring the viewstate of a timebarviewer. When dealing with hierarchical
 * models a HierarchyIdService is needed for identifying the nodes.
 * 
 * @author kliem
 * @version $Id: IViewstateSaver.java 340 2007-04-02 21:52:03Z olk $
 */
public interface IViewstateSaver {
    /**
     * Save the viewstate. Previously saved state will be overwritten.
     * 
     * @param timeBarViewer viewer to save state of
     * @param idService HierarchyIdService needed when handling hierarchical models. May be <code>null</code> when 
     * dealing with a flat model
     * @param id id used to create a child memento when not <code>null</code>
     * @param memento memento to write to
     */
    void saveViewstate(TimeBarViewer timeBarViewer, IHierarchyIdService idService, String id, IMemento memento);
    /**
     * Restore the viewstate. Will not fail if no state can be found in the memento.
     * 
     * @param timeBarViewer viewer to restore state of
     * @param idService HierarchyIdService needed when handling hierarchical models. May be <code>null</code> when 
     * dealing with a flat model
     * @param id id of a child memento to read from. May be <code>null</code>.
     * @param memento memento to read from
     */
    void restoreViewstate(TimeBarViewer timeBarViewer, IHierarchyIdService idService, String id, IMemento memento);

}
