/*
 *  File: IdentificableIdService.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.util.ui.timebars.addon;

import de.jaret.util.ui.timebars.model.HierarchicalTimeBarModel;
import de.jaret.util.ui.timebars.model.IIdentifiableTimeBarNode;
import de.jaret.util.ui.timebars.model.TimeBarNode;

/**
 * Id service for use with models that contain IIdentifiableTimeBarNodes.
 * 
 * @author kliem
 * @version $Id: $
 */
public class IdentifiableIdService implements IHierarchyIdService {

    /**
     * {@inheritDoc}
     */
    public String getId(HierarchicalTimeBarModel model, TimeBarNode node) {
        if (node instanceof IIdentifiableTimeBarNode) {
            return ((IIdentifiableTimeBarNode) node).getId();
        }
        return "irrelevant";
    }

    /**
     * {@inheritDoc}
     */
    public TimeBarNode getNode(HierarchicalTimeBarModel model, String id) {
        TimeBarNode node = getNodeById(model.getRootNode(), id);
        if (node != null) {
            return node;
        }
        return null;
    }

    /**
     * Traverse the model beginning with the given node and search for a node with the given id.
     * 
     * @param node starting node
     * @param id id to search
     * @return node carrying the id or <code>null</code>
     */
    private TimeBarNode getNodeById(TimeBarNode node, String id) {
        if (node instanceof IIdentifiableTimeBarNode) {
            if (((IIdentifiableTimeBarNode) node).getId().equals(id)) {
                return node;
            }
        }
        for (TimeBarNode child : node.getChildren()) {
            TimeBarNode result = getNodeById(child, id);
            if (result != null) {
                return result;
            }
        }
        return null;
    }

}
