/*
 *  File: SimplePredecessorRenderer.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.examples.timebars.addon.hierarchy.swt;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.printing.Printer;

import de.jaret.examples.timebars.addon.hierarchy.model.DemoTimeBarNode;
import de.jaret.examples.timebars.addon.hierarchy.swt.SimplePredecessorRenderer;
import de.jaret.util.date.Interval;
import de.jaret.util.ui.timebars.TimeBarViewerDelegate;
import de.jaret.util.ui.timebars.model.TimeBarRow;
import de.jaret.util.ui.timebars.swt.renderer.GlobalAssistantRenderer;
import de.jaret.util.ui.timebars.swt.renderer.RendererBase;

/**
 * Simple renderer for the predecessor relation on DemoTimeBarNodes (hack, could
 * be done smarter).
 * 
 * @author Peter Kliem
 * @version $Id: SimplePredecessorRenderer.java 536 2007-08-19 10:49:10Z olk $
 */
public class SimplePredecessorRenderer extends RendererBase implements GlobalAssistantRenderer {

    public SimplePredecessorRenderer(Printer printer) {
        super(printer);
    }

    public SimplePredecessorRenderer() {
        super(null);
    }

    public void doRenderingBeforeIntervals(TimeBarViewerDelegate delegate, GC gc, boolean printing) {
    }

    public void doRenderingLast(TimeBarViewerDelegate delegate, GC gc, boolean printing) {
        _cache = new ArrayList<Line>(200);

        int rowHeight = delegate.getRowHeight();
        int firstRow = delegate.getFirstRow();

        // set the clipping to include only the heigth of the diagram rect
        Rectangle clipSave = gc.getClipping();
        Rectangle nc = new Rectangle(delegate.getDiagramRect().x, delegate.getDiagramRect().y, delegate
                .getDiagramRect().width, delegate.getDiagramRect().height);
        gc.setClipping(gc.getClipping().intersection(nc));

        int upperYBound = delegate.getDiagramRect().y;
        int lowerYBound = upperYBound + delegate.getDiagramRect().height;
        if (gc.isClipped()) {
            upperYBound = gc.getClipping().y;
            lowerYBound = upperYBound + gc.getClipping().height;
        }

        int rowsDisplayed = delegate.getRowsDisplayed();
        for (int r = firstRow; r <= firstRow + rowsDisplayed + 1 && r < delegate.getRowCount(); r++) {
            int y = (r - firstRow) * rowHeight + delegate.getDiagramRect().y - delegate.getFirstRowOffset();
            // row is drawn if either the beginning or the end is inside the
            // clipping rect
            // or if the upperBound is inside the row rect (clipping rect is
            // inside the row rect
            if ((y >= upperYBound && y <= lowerYBound)
                    || (y + rowHeight >= upperYBound && y + rowHeight <= lowerYBound)
                    || (upperYBound > y && upperYBound < y + rowHeight)) {
                drawRow(delegate, gc, delegate.getRow(r), y, printing);
            }
        }
        gc.setClipping(clipSave);

    }

    private void drawRow(TimeBarViewerDelegate _delegate, GC gc, TimeBarRow row, int y, boolean printing) {
        // some code left in commented to show interval handling
        // the demo concentrates on rows that exactly represent one interval

        // JaretDate start = _delegate.getStartDate();
        // JaretDate end = _delegate.getEndDate();
        // List<Interval> intervalsUnfiltered = row.getIntervals(start, end);
        // List<Interval> intervals = new ArrayList<Interval>();

        // apply filter on intervals if set
        // if (_delegate.getIntervalFilter() != null) {
        // for (Interval i : intervalsUnfiltered) {
        // if (_delegate.getIntervalFilter().isInResult(i)) {
        // intervals.add(i);
        // }
        // }
        // } else {
        // intervals = intervalsUnfiltered;
        // }

        // if (_delegate.isDrawOverlapping()) {
        // for (Interval i : intervals) {
        // RenderDelegate.drawInterval(_delegate, _renderer, false, gc, y, i,
        // _delegate.getSelectionModel().isSelected(i));
        // }
        // } else {
        // for (Interval i : intervals) {
        // RenderDelegate.drawInterval(_delegate, _renderer, false, gc, y, i,
        // _delegate.getOverlapInfo(row, i));
        // }
        // }

        if (row instanceof DemoTimeBarNode) {
            DemoTimeBarNode node = (DemoTimeBarNode) row;
            if (node.getPredecessor() != null) {
                Interval p = node.getIntervals().get(0);
                Point endPoint = new Point(_delegate.xForDate(p.getBegin()), y + (_delegate.getRowHeight() / 2));
                Point begin = getBeginPoint(_delegate, node.getPredecessor());
                draw(gc, node.getPredecessor(), begin, endPoint, _delegate.getRowHeight());
            }
            // following ensures that the link is painted even if the successor node is not visible
            if (node.getSuccessor() != null) {
                node = node.getSuccessor();
                y+=_delegate.getRowHeight();
                Interval p = node.getIntervals().get(0);
                Point endPoint = new Point(_delegate.xForDate(p.getBegin()), y + (_delegate.getRowHeight() / 2));
                Point begin = getBeginPoint(_delegate, node.getPredecessor());
                draw(gc, node.getPredecessor(), begin, endPoint, _delegate.getRowHeight());
            }
        }

    }

    public class Line {
        public DemoTimeBarNode node;
        public int x1;
        public int y1;
        public int x2;
        public int y2;

        public Line(DemoTimeBarNode node, int x1, int y1, int x2, int y2) {
            this.node = node;
            this.x1 = x1;
            this.y1 = y1;
            this.x2 = x2;
            this.y2 = y2;
        }

        public boolean hit(int x, int y, int tolerance) {
            if (x1 == x2) {
                if (x1 - tolerance <= x && x <= x1 + tolerance) {
                    if ((y1 < y2 && y1 - tolerance <= y && y <= y2 + tolerance)
                            || (y2 < y1 && y2 - tolerance <= y && y <= y1 + tolerance)) {
                        return true;
                    }
                }
            } else {
                if (y1 == y2) {
                    if (y1 - tolerance <= y && y <= y1 + tolerance) {
                        if ((x1 < x2 && x1 - tolerance <= x && x <= x2 + tolerance)
                                || (x2 < x1 && x2 - tolerance <= x && x <= x1 + tolerance)) {
                            return true;
                        }
                    }
                }
            }
            return false;
        }
    }

    private List<Line> _cache;

    private void drawLine(GC gc, DemoTimeBarNode pred, int x1, int y1, int x2, int y2) {
        _cache.add(new Line(pred, x1, y1, x2, y2));
        gc.drawLine(x1, y1, x2, y2);
    }

    private void draw(GC gc, DemoTimeBarNode pred, Point begin, Point end, int rheight) {
        int off = scaleX(8);

        int ydir = end.y > begin.y ? 1 : -1;
        int xdir = end.x > begin.x ? 1 : -1;

        drawLine(gc, pred, begin.x, begin.y, begin.x + off, begin.y);

        drawLine(gc, pred, begin.x + off, begin.y, begin.x + off, begin.y + (rheight / 2 * ydir));
        drawLine(gc, pred, begin.x + off, begin.y + (rheight / 2 * ydir), end.x - off, begin.y + (rheight / 2 * ydir));
        drawLine(gc, pred, end.x - off, begin.y + (rheight / 2 * ydir), end.x - off, end.y);

        drawLine(gc, pred, end.x - off, end.y, end.x, end.y);

        drawArrow(gc, end);
    }

    private void drawArrow(GC gc, Point p) {
        int off = scaleX(5);
        gc.drawLine(p.x, p.y, p.x - off, p.y - off);
        gc.drawLine(p.x, p.y, p.x - off, p.y + off);
        gc.drawLine(p.x - off, p.y - off, p.x - off, p.y + off);

    }

    private Point getBeginPoint(TimeBarViewerDelegate _delegate, DemoTimeBarNode predecessor) {
        int y = _delegate.yForRow(predecessor);
        Interval i = predecessor.getIntervals().get(0);
        int x = _delegate.xForDate(i.getEnd());
        Point p = new Point(x, y + _delegate.getRowHeight() / 2);
        return p;
    }

    DemoTimeBarNode hitPredecessor(int x, int y) {
        for (Line line : _cache) {
            if (line.hit(x, y, 1)) {
                return line.node;
            }
        }
        ;
        return null;
    }

    public void dispose() {
        _cache = null;
    }

    public GlobalAssistantRenderer createPrintRenderer(Printer printer) {
        return new SimplePredecessorRenderer(printer);
    }

}
