/*
 *  File: SwtHierarchyControlPanel.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.examples.timebars.addon.hierarchy.swt;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Scale;

import de.jaret.examples.timebars.addon.hierarchy.swt.SwtHierarchyControlPanel;
import de.jaret.util.ui.timebars.swt.TimeBarViewer;
import de.jaret.util.ui.timebars.swt.renderer.DefaultHierarchyRenderer;

/**
 * Hierarhy settings for the hierachy example.
 * 
 * @author Peter Kliem
 * @version $Id: SwtHierarchyControlPanel.java 392 2007-04-30 23:59:46Z olk $
 */
public class SwtHierarchyControlPanel extends Composite {

    private TimeBarViewer _tbv;

    public SwtHierarchyControlPanel(Composite parent, int style, TimeBarViewer tbv) {
        super(parent, style);
        _tbv = tbv;
        createControls(this);
    }

    /**
     * @param panel
     */
    private void createControls(SwtHierarchyControlPanel panel) {
        panel.setLayout(new RowLayout());

        final DefaultHierarchyRenderer renderer = (DefaultHierarchyRenderer) _tbv.getHierarchyRenderer();

        Label l = new Label(this, SWT.NULL);
        l.setText("Levelwidth:");

        final Scale levelWidthScale = new Scale(this, SWT.HORIZONTAL);
        levelWidthScale.setMaximum(300);
        levelWidthScale.setMinimum(5);
        levelWidthScale.setSelection(renderer.getLevelWidth());
        levelWidthScale.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent ev) {
                int val = levelWidthScale.getSelection();
                renderer.setLevelWidth(val);
                _tbv.redraw();
            }
        });

        final Button fixedLevelCheck = new Button(this, SWT.CHECK);
        fixedLevelCheck.setText("fixed level width");
        fixedLevelCheck.setSelection(renderer.getFixedLevelWidth());
        fixedLevelCheck.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent arg0) {
                renderer.setFixedLevelWidth(fixedLevelCheck.getSelection());
                _tbv.redraw();
            }
        });

        final Button drawIconsCheck = new Button(this, SWT.CHECK);
        drawIconsCheck.setText("Draw icons");
        drawIconsCheck.setSelection(renderer.getDrawIcons());
        drawIconsCheck.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent arg0) {
                renderer.setDrawIcons(drawIconsCheck.getSelection());
                _tbv.redraw();
            }
        });

        final Button drawLabelsCheck = new Button(this, SWT.CHECK);
        drawLabelsCheck.setText("Draw labels");
        drawLabelsCheck.setSelection(renderer.getDrawLabels());
        drawLabelsCheck.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent arg0) {
                renderer.setDrawLabels(drawLabelsCheck.getSelection());
                _tbv.redraw();
            }
        });

        final Button symbolCheck = new Button(this, SWT.CHECK);
        symbolCheck.setText("Default symbols");
        symbolCheck.setSelection(false);
        symbolCheck.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent arg0) {
                if (symbolCheck.getSelection()) {
                    renderer.setRscNames(null, null, null);
                    renderer.setSize(12);
                } else {
                    renderer.setRscNames("/de/jaret/examples/timebars/hierarchy/swt/collapsed.png",
                            "/de/jaret/examples/timebars/hierarchy/swt/expanded.png",
                            "/de/jaret/examples/timebars/hierarchy/swt/leaf.png");
                    renderer.setSize(16);
                }
                _tbv.redraw();
            }
        });


        final Button drawTreeCheck = new Button(this, SWT.CHECK);
        drawTreeCheck.setText("Draw tree");
        drawTreeCheck.setSelection(renderer.getDrawTreeLines());
        drawTreeCheck.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent arg0) {
                renderer.setDrawTreeLines(drawTreeCheck.getSelection());
                _tbv.redraw();
            }
        });

        
        l = new Label(this, SWT.NULL);
        l.setText("Hierarchy width:");

        final Scale hierarchyWidthScale = new Scale(this, SWT.HORIZONTAL);
        hierarchyWidthScale.setMaximum(400);
        hierarchyWidthScale.setMinimum(0);
        hierarchyWidthScale.setSelection(_tbv.getHierarchyWidth());
        hierarchyWidthScale.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent ev) {
                int val = hierarchyWidthScale.getSelection();
                _tbv.setHierarchyWidth(val);
                _tbv.redraw();
            }
        });
        
        l = new Label(this, SWT.NULL);
        l.setText("Header (yaxis) width:");

        final Scale headerWidthScale = new Scale(this, SWT.HORIZONTAL);
        headerWidthScale.setMaximum(300);
        headerWidthScale.setMinimum(0);
        headerWidthScale.setSelection(_tbv.getYAxisWidth());
        headerWidthScale.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent ev) {
                int val = headerWidthScale.getSelection();
                _tbv.setYAxisWidth(val);
                _tbv.redraw();
            }
        });
        
        
        
    }

}
