/*
 *  File: AppointmentModificator.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.examples.timebars.calendar.model;

import de.jaret.util.date.Interval;
import de.jaret.util.date.JaretDate;
import de.jaret.util.ui.timebars.mod.IntervalModificator;
import de.jaret.util.ui.timebars.model.TimeBarRow;

/**
 * Simple modificator for the calendar example.
 * @author kliem
 * @version $Id: AppointmentModificator.java 716 2008-02-18 23:21:09Z kliem $
 */
public class AppointmentModificator implements IntervalModificator {

    /**
     * {@inheritDoc}
     */
    public double getSecondGridSnap() {
        return 300;
    }

    /**
     * {@inheritDoc}
     */
    public boolean isShiftingAllowed(TimeBarRow row, Interval interval) {
        return ((Appointment) interval).isEditable();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isSizingAllowed(TimeBarRow row, Interval interval) {
        return ((Appointment) interval).isEditable();
    }

    /**
     * {@inheritDoc}
     */
    public boolean newBeginAllowed(TimeBarRow row, Interval interval, JaretDate newBegin) {
        return CalendarModel.BASEDATE.compareDateTo(newBegin) == 0;
    }

    /**
     * {@inheritDoc}
     */
    public boolean newEndAllowed(TimeBarRow row, Interval interval, JaretDate newEnd) {
        return CalendarModel.BASEDATE.compareDateTo(newEnd) == 0;
    }

    /**
     * {@inheritDoc}
     */
    public boolean shiftAllowed(TimeBarRow row, Interval interval, JaretDate newBegin) {
        return CalendarModel.BASEDATE.compareDateTo(newBegin) == 0
                && CalendarModel.BASEDATE.compareDateTo(newBegin.copy().advanceSeconds(interval.getSeconds())) == 0;
    }

    /**
     * {@inheritDoc}
     */
    public boolean isApplicable(TimeBarRow row, Interval interval) {
        return true;
    }

}
