/*
 *  File: CalendarWeekRow.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.examples.timebars.calendar.model;

import de.jaret.util.ui.table.model.IRow;

/**
 * Row implementation representing a row in a year.
 * 
 * @author kliem
 * @version $Id: CalendarWeekRow.java 716 2008-02-18 23:21:09Z kliem $
 */
public class CalendarWeekRow implements IRow {
    /** year of the week. */
    protected int _year;
    /** week of the year. */
    protected int _week;
    /** corresponding month table model. */
    protected MonthTableModel _tableModel;

    /**
     * Construct a week.
     * 
     * @param tableModel month table model the week is used in
     * @param year year of the week
     * @param week week in the year
     */
    public CalendarWeekRow(MonthTableModel tableModel, int year, int week) {
        _tableModel = tableModel;
        _year = year;
        _week = week;
    }

    /**
     * {@inheritDoc}
     */
    public String getId() {
        return "week" + _year + "/" + _week;
    }

    /**
     * Retrieve the year of the row.
     * 
     * @return year
     */
    public int getYear() {
        return _year;
    }

    /**
     * Retriveth enumber of the week in the year for the row.
     * 
     * @return week of the year
     */
    public int getWeek() {
        return _week;
    }

}
