/*
 *  File: WeekDayColumn.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package de.jaret.examples.timebars.calendar.model;

import java.text.DateFormatSymbols;
import java.util.Calendar;
import java.util.GregorianCalendar;

import de.jaret.util.date.JaretDate;
import de.jaret.util.ui.table.model.AbstractColumn;
import de.jaret.util.ui.table.model.IRow;

/**
 * Column implementation representing a weekday in a month table model.
 * 
 * @author kliem
 * @version $Id: WeekDayColumn.java 747 2008-04-12 08:56:13Z kliem $
 */
public class WeekDayColumn extends AbstractColumn {

    /** weekday coded 1 based. */
    protected int _weekday;
    /** corresponding month table model. */
    protected MonthTableModel _tableModel;
    /** calendar instance for calculations. */
    protected Calendar _calendar = GregorianCalendar.getInstance();

    /** date format symbols instance. */
    protected static DateFormatSymbols _dateFormatSymbols;

    /**
     * Create a weekday column.
     * 
     * @param tableModel the month table model the column i sused in
     * @param weekday the weekday (1 based)
     */
    public WeekDayColumn(MonthTableModel tableModel, int weekday) {
        _tableModel = tableModel;
        _weekday = weekday;

        // TODO locale
        _dateFormatSymbols = new DateFormatSymbols(); // java 6: .getInstance();
    }

    /**
     * {@inheritDoc}
     */
    public Class<?> getContentClass() {
        return Day.class;
    }

    /**
     * {@inheritDoc}. Header label is the weekday.
     */
    public String getHeaderLabel() {
        return _dateFormatSymbols.getWeekdays()[_weekday];
    }

    /**
     * {@inheritDoc}
     */
    public String getId() {
        return "weekday" + _weekday;
    }

    /**
     * {@inheritDoc}
     */
    public Object getValue(IRow row) {
        CalendarWeekRow cwr = (CalendarWeekRow) row;

        _calendar.set(Calendar.YEAR, cwr.getYear());
        _calendar.set(Calendar.WEEK_OF_YEAR, cwr.getWeek());
        _calendar.set(Calendar.DAY_OF_WEEK, _weekday);
        JaretDate dayDate = new JaretDate(_calendar.getTime().getTime());

        Day day = _tableModel.getCalendarModel().getDay(dayDate);
        return day;
    }

    /**
     * {@inheritDoc} No support for value setting.
     */
    public void setValue(IRow row, Object value) {
    }

    /**
     * {@inheritDoc} No sorting.
     */
    public boolean supportsSorting() {
        return false;
    }

    /**
     * {@inheritDoc} no sorting.
     */
    public int compare(IRow o1, IRow o2) {
        return 0;
    }

}
