/*
 *  File: MonthView.java 
 *  Copyright (c) 2004-2007  Peter Kliem (Peter.Kliem@jaret.de)
 *  A commercial license is available, see http://www.jaret.de.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jaret.examples.timebars.calendar.swt;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;

import de.jaret.examples.timebars.calendar.model.CalendarModel;
import de.jaret.examples.timebars.calendar.model.Day;
import de.jaret.examples.timebars.calendar.model.ModelCreator;
import de.jaret.examples.timebars.calendar.model.MonthTableModel;
import de.jaret.examples.timebars.calendar.swt.renderer.DayCellRenderer;
import de.jaret.util.ui.table.JaretTable;
import de.jaret.util.ui.table.model.IColumn;
import de.jaret.util.ui.table.model.IJaretTableModel;
import de.jaret.util.ui.table.model.ITableViewState;
import de.jaret.util.ui.table.renderer.DefaultTableHeaderRenderer;

/**
 * A shell showing a month in a grid fashion. Operates on a calendar model.
 * 
 * @author Peter Kliem
 * @version $Id: MonthView.java 712 2008-02-13 23:31:18Z kliem $
 */
public class MonthView {
    Shell _shell;
    IJaretTableModel _tableModel;
    CalendarModel _calendarModel;
    
    public MonthView(CalendarModel calendarModel) {
        _calendarModel = calendarModel;;
        _shell = new Shell(Display.getCurrent());
        _shell.setText("month view");
        createControls();
        _shell.open();
        Display display;
        display = _shell.getDisplay();
        _shell.pack();
        _shell.setSize(1000, 700);

        /*
         * do the event loop until the shell is closed to block the call
         */
        while (_shell != null && !_shell.isDisposed()) {
            try {
                if (!display.readAndDispatch())
                    display.sleep();
            } catch (Throwable e) {
                e.printStackTrace();
            }
        }
        display.update();
    }

    JaretTable _jt;

    /**
     * Create the controls that compose the console test.
     * 
     */
    protected void createControls() {
        GridLayout gl = new GridLayout();
        gl.numColumns = 1;
        _shell.setLayout(gl);

        GridData gd = new GridData(GridData.FILL_BOTH);

        _jt = new JaretTable(_shell, SWT.V_SCROLL | SWT.H_SCROLL);
        _jt.setLayoutData(gd);

        // register the day cell renderer
        _jt.registerCellRenderer(Day.class, new DayCellRenderer());
        
        // use fixed row heights
        _jt.getTableViewState().setRowHeightMode(ITableViewState.RowHeightMode.FIXED);
        _jt.getTableViewState().setRowHeight(150);
        
        // disallow fill dragging
        _jt.setSupportFillDragging(false);
        
        // setup the default header renderer
        DefaultTableHeaderRenderer headerRenderer = (DefaultTableHeaderRenderer)_jt.getHeaderRenderer();
        headerRenderer.setAlignment(DefaultTableHeaderRenderer.Alignment.CENTER);
        headerRenderer.setDrawBox(false);
        headerRenderer.setBackgroundRGB(new RGB(255,255,255));
        
        FontData fontData = new FontData("Arial", 11, SWT.BOLD);
        headerRenderer.setFontData(fontData);
        
        
        MonthTableModel monthTableModel = new MonthTableModel(_calendarModel, 4, 2007);
 
        for (int i=0; i<monthTableModel.getColumnCount(); i++) {
            IColumn column = monthTableModel.getColumn(i);
            // default the col width
            _jt.getTableViewState().setColumnWidth(column, 150);
        }
 
        
        _tableModel = monthTableModel;
        _jt.setTableModel(_tableModel);

    }

    public static void main(String args[]) {
        CalendarModel calendarModel = (CalendarModel)ModelCreator.createCalendarModel();
        MonthView te = new MonthView(calendarModel);
    }

}
